@@ -15,7 +15,7 @@ logging.basicConfig(
 )
 
 
-class DBConnect():
+class DBConnect:
     def __init__(self, db: str, collection: str, home_kye='MONGODB_HOST', port_kye='MONGODB_PORT'):
         self.mongo_home = os.environ.get(home_kye, None)
         self.mongo_port = os.environ.get(port_kye, 27017)
@@ -35,7 +35,7 @@ class DBConnect():
             if not docu.__contains__('creation_time'):
                 docu['creation_time'] = datetime.today()
             new_data = self.mongo_collection.insert_one(docu)
-            return new_data.inserted_id
+            return str(new_data.inserted_id)
         except Exception as err:
             str_data = 'MongoDB(组件)出现写入错误: {0}'.format(err)
             logging.warning(str_data)
@@ -66,7 +66,7 @@ class DBConnect():
             logging.warning(str_data)
             abort(Response(str_data, 500, {}))
 
-    def delete_docu(self, find_docu: dict, many: bool = False, false_delete: bool = False) -> list:
+    def delete_docu(self, find_docu: dict, many: bool = False, false_delete: bool = False) -> dict:
         try:
             if false_delete:
                 # 假删除流程
@@ -122,15 +122,15 @@ class DBConnect():
         :return: 将结果转换为字典
         """
         if not isinstance(id, str):
-            logging.warning("类型错误，预期 %s ,却得到 %s" % (list, type(id)))
-            abort(Response("类型错误，预期 %s ,却得到 %s" % (list, type(id)), 400, {}))
+            logging.warning("类型错误，预期 %s ,却得到 %s" % (str, type(id)))
+            abort(Response("类型错误，预期 %s ,却得到 %s" % (str, type(id)), 400, {}))
         entity = self.find_docu({'id': id}, many=False)
         if entity is None or len(entity) == 0:
             if raise_err:
                 logging.warning('找不到 id= %s 的记录' % (id,))
                 abort(Response('找不到 id= %s 的记录' % (id,), 400, {}))
             else:
-                return None
+                return {}
         return entity[0]
 
     def find_docu_by_id_list(self, id_list: list) -> list:
@@ -176,63 +176,63 @@ class DBConnect():
             end_date = handle_date(date=param['end_date'], date_type='end')
             if len(columns) != len(sort_order) or len(columns) != len(filtered_value):
                 raise Exception('三个控制列表的长度不一致')
+            # 查找假删除数据的数据量
+            remove_count = self.mongo_collection.find(
+                {'remove_time': {'$exists': True}}).count()
+            # 查找字典和排序列表，处理假删除数据
+            find_dict = handle_db_remove({})
+            sort_list = []
+            if len(columns):
+                for i in range(len(columns)):
+                    # 整理请求参数中的筛选项字典
+                    if type(filtered_value[i]) == int:
+                        find_dict[columns[i]] = filtered_value[i]
+                    elif columns[i] == 'id' or columns[i] == '_id':
+                        find_dict['_id'] = ObjectId(str(filtered_value[i]))
+                    else:
+                        if filtered_value[i].strip() != '':
+                            find_dict[columns[i]] = {'$regex': filtered_value[i]}
+                    # 整理请求参数中的筛排序列表
+                    if type(sort_order[i]) != str:
+                        abort(Response('计算组件分页参数异常: 排序参数不支持 int 类型', 400, {}))
+                    sort_value = sort_order[i].strip()
+                    if sort_value == 'asc':
+                        sort_list.append((columns[i], pymongo.ASCENDING))
+                    elif sort_value == 'desc':
+                        sort_list.append((columns[i], pymongo.DESCENDING))
+                    elif sort_value == '':
+                        pass
+                    else:
+                        abort(Response('计算组件分页参数异常: 仅支持 asc 和 desc 两个值', 400, {}))
+            # 仅存在日期查询区间参数时，进行额外的创建时间区间查询
+            if start_date and end_date:
+                find_dict['creation_time'] = {
+                    '$gte': start_date, '$lte': end_date}
+            find_data = self.mongo_collection.find(find_dict)
+            records_filtered = find_data.count()
+            if not records_filtered:
+                return {
+                    'records_total': self.mongo_collection.estimated_document_count() - remove_count,
+                    'records_filtered': 0,
+                    'query_result': [],
+                    'total_pages': 0,
+                    'remove_count': remove_count,
+                }
+            if sort_list:
+                find_data.sort(sort_list).limit(
+                    page_size).skip(page_size * current)
+            else:
+                find_data.limit(page_size).skip(page_size * current)
+            # 处理返回数据
+            query_result = handle_db_to_list(find_data)
+            return {
+                'records_total': self.mongo_collection.estimated_document_count() - remove_count,
+                'records_filtered': records_filtered,
+                'query_result': query_result,
+                'total_pages': math.ceil(records_filtered / page_size),
+                'remove_count': remove_count,
+            }
         except Exception as err:
             str_data = '计算组件分页参数异常: {0}'.format(err)
             logging.warning(str_data)
             abort(Response(str_data, 400, {}))
-        # 查找假删除数据的数据量
-        remove_count = self.mongo_collection.find(
-            {'remove_time': {'$exists': True}}).count()
-        # 查找字典和排序列表，处理假删除数据
-        find_dict = handle_db_remove({})
-        sort_list = []
-        if len(columns):
-            for i in range(len(columns)):
-                # 整理请求参数中的筛选项字典
-                if type(filtered_value[i]) == int:
-                    find_dict[columns[i]] = filtered_value[i]
-                elif columns[i] == 'id' or columns[i] == '_id':
-                    find_dict['_id'] = ObjectId(str(filtered_value[i]))
-                else:
-                    if filtered_value[i].strip() != '':
-                        find_dict[columns[i]] = {'$regex': filtered_value[i]}
-                # 整理请求参数中的筛排序列表
-                if type(sort_order[i]) != str:
-                    abort(Response('计算组件分页参数异常: 排序参数不支持 int 类型', 400, {}))
-                sort_value = sort_order[i].strip()
-                if sort_value == 'asc':
-                    sort_list.append((columns[i], pymongo.ASCENDING))
-                elif sort_value == 'desc':
-                    sort_list.append((columns[i], pymongo.DESCENDING))
-                elif sort_value == '':
-                    pass
-                else:
-                    abort(Response('计算组件分页参数异常: 仅支持 asc 和 desc 两个值', 400, {}))
-        # 仅存在日期查询区间参数时，进行额外的创建时间区间查询
-        if start_date and end_date:
-            find_dict['creation_time'] = {
-                '$gte': start_date, '$lte': end_date}
-        find_data = self.mongo_collection.find(find_dict)
-        records_filtered = find_data.count()
-        if not records_filtered:
-            return {
-                'records_total': self.mongo_collection.estimated_document_count()-remove_count,
-                'records_filtered': 0,
-                'query_result': [],
-                'total_pages': 0,
-                'remove_count': remove_count,
-            }
-        if sort_list:
-            find_data.sort(sort_list).limit(
-                page_size).skip(page_size * current)
-        else:
-            find_data.limit(page_size).skip(page_size * current)
-        # 处理返回数据
-        query_result = handle_db_to_list(find_data)
-        return {
-            'records_total': self.mongo_collection.estimated_document_count()-remove_count,
-            'records_filtered': records_filtered,
-            'query_result': query_result,
-            'total_pages': math.ceil(records_filtered / page_size),
-            'remove_count': remove_count,
-        }
