@@ -1,4 +1,8 @@
+from flask_cors import CORS
+
+
 def error_handler(app):
+    CORS(app, supports_credentials=True)
 
     @app.errorhandler(400)
     def handle_400_error(error):
