@@ -58,6 +58,9 @@ def handle_db_dict(db_dict: dict) -> dict:
 
 
 def handle_db_id(data_dict: dict) -> dict:
+    if not isinstance(data_dict, dict):
+        logging.warning("类型错误，预期 %s ,却得到 %s" % (dict, type(id)))
+        abort(Response("类型错误，预期 %s ,却得到 %s" % (dict, type(id)), 400, {}))
     try:
         if data_dict.__contains__('_id'):
             data_dict['_id'] = ObjectId(str(data_dict['_id']))
@@ -74,7 +77,9 @@ def handle_db_id(data_dict: dict) -> dict:
 def handle_db_remove(find_dict: dict) -> dict:
     try:
         if not find_dict.__contains__('remove_time'):
+            # 设置搜索条件为不存在remove_time字段的文件
             find_dict['remove_time'] = {'$exists': False}
+        # 返回设置后的搜索条件
         return find_dict
     except Exception as err:
         str_data = 'MongoDB 移除数据处理异常: {0}'.format(err)
